@@ -12,7 +12,7 @@ from datetime import datetime, date, time
 from google.cloud.bigquery.dataset import DatasetReference
 import uuid
 
-logger = logging.getLogger('debug')
+logger = logging.getLogger('import')
 
 def create_bigquery_client(info=None, credential_filepath=None):
     if info:
@@ -29,7 +29,8 @@ def create_bigquery_client(info=None, credential_filepath=None):
                                                                     ]
                                                             )
 
-    client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred, location=lib_conf.BIGQUERY_GCLOUD_LOCATION)
+    #client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred, location=lib_conf.BIGQUERY_GCLOUD_LOCATION)
+    client = bigquery.Client(project=lib_conf.BIGQUERY_GCLOUD_PROJECT_ID, credentials=cred)
     
     return client 
 
@@ -232,8 +233,13 @@ def stream_data(bigquery_client, dataset_name, table_template_name, table_scheme
             
         serialize_data_to_stream_list.append(serialized_dict)
         
+    logger.debug('serialize_data_to_stream_list=%s' , serialize_data_to_stream_list)
             
     __errors = bigquery_client.insert_rows_json(created_table, serialize_data_to_stream_list)
+    
+    logger.debug('==============================================')
+    logger.debug('__errors=%s' , __errors)
+    logger.debug('==============================================')
             
     if len(__errors)>0:
         errors.extend(__errors)
@@ -246,6 +252,7 @@ def stream_data_by_datetime_partition(bigquery_client, dataset_name, table_templ
     errors                      = []
     partition_date_formation    = None
     logger.debug('table_scheme=%s' , table_scheme)
+    logger.debug('column_name_used_to_partition=%s' , column_name_used_to_partition)
     
     if column_name_used_to_partition and (partition_date or partition_month or partition_year):
         logger.debug('partition_date=%s' , partition_date)
@@ -267,14 +274,17 @@ def stream_data_by_datetime_partition(bigquery_client, dataset_name, table_templ
     for table_name_suffix, data_list_to_stream in data_dict_to_stream.items():
     
         partition_dict              =  {}
-        
+        partition_value_str         = ''
         #partition data first
         for data_dict in data_list_to_stream:
             if partition_date_formation:
                 partition_value         = data_dict.get(column_name_used_to_partition)
-                partition_value_str     = partition_value.strftime(partition_date_formation)
-            else:
-                partition_value_str     = ''    
+                
+                logger.debug('partition_value=%s', partition_value)
+                
+                if partition_value:
+                    partition_value_str     = partition_value.strftime(partition_date_formation)
+                
             
             partition_list = partition_dict.get(partition_value_str)
             if partition_list is None:
@@ -353,4 +363,3 @@ def process_job_result_into_category_and_count(job_result_rows):
     return row_list          
         
     
-    
